pqp package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pqp.data
   pqp.estimation
   pqp.identification
   pqp.refutation
   pqp.symbols
   pqp.utils

Submodules
----------

pqp.pqp module
--------------

.. automodule:: pqp.pqp
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pqp
   :members:
   :undoc-members:
   :show-inheritance:
